/**
 * P4
 * http://snarfed.org/space/p4
 *
 * Copyright 2001-2004
 * Ken Ashcraft <kashcraft+p4@gmail.com>
 * Ryan Barrett <p4@ryanb.org>
 * Maulik Shah <p4@maulik.net>
 * Nathan Stoll <nathanstoll+p4@gmail.com>
 *
 * @file msg_ping.cpp
 *
 * Defines the cmsg_ping class, which is derived from the abstract cmsg class.
 * The cmsg_ping class is the class that PING messages instantiate. For more
 * information, see protocol.txt, msg.h, and protocol.h.
 *
 * TODO: virt_process is horribly ugly. fix it, and please, for god's sake,
 *       make cconn::send() protected again!
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the Free
 * Software Foundation; either version 2 of the License, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
 * more details.
 *
 * You should have received a copy of the GNU General Public License along with
 * this program; if not, write to the Free Software Foundation, Inc., 59 Temple
 * Place, Suite 330, Boston, MA 02111-1307 USA
 */

#include "msg_ping.h"
#include "msg_ping_ack.h"
#include "conn.h"
#include "conn_mgr.h"
#include "debug.h"
#include "p4error.h"

/*****************************************************************************
 * PROTECTED METHODS
 *****************************************************************************/

bool cmsg_ping::virt_process() const
{
  cconn &conn = cconn_mgr::instance().get_conn(hdr.username);
  if (conn.get_status() == cconn::efailed) {
    cdebug::instance() << acquire("msg_debug")
                       << "msg_ping::virt_procees().  could not respond to"
                       << hdr.username
                       << release();
    assert(0);
  }
  
  cmsg_ping_ack mc;
  
  if (conn.send(mc) != kerr_success) {
    cdebug::instance() << acquire("msg_debug")
                       << "msg_ping::virt_process(). could not respond to"
                       << hdr.username
                       << release();
  }    

  return true;
}


#ifdef MSG_PING_MAIN
int main(int argc, char **argv)
{
  cmsg_ping p;
  string name = "testname";
  p.send(name);
}
#endif // MSG_PING_MAIN
